\\ Copyright 2022 Kevin Ryde
\\
\\ This file is free software; you can redistribute it and/or modify it
\\ under the terms of the GNU General Public License as published by the Free
\\ Software Foundation; either version 3, or (at your option) any later
\\ version.
\\
\\ This file is distributed in the hope that it will be useful, but
\\ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
\\ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
\\ for more details.
\\
\\ You should have received a copy of the GNU General Public License along
\\ with this file.  See the file COPYING.  If not, see
\\ <http://www.gnu.org/licenses/>.


\\ Usage: gp <example-data.gp
\\
\\ Simple uses of OEIS-data.gp.
\\ Be sure to have OEIS-data-reader somewherein $PATH rady to run.
\\
\\ Running this script will require file
\\ 
\\     ~/OEIS/A123456.internal.txt
\\     
\\ downloaded by for instance
\\
\\     mkdir -p $HOME/OEIS
\\     wget -O $HOME/OEIS/A123456.internal.txt \
\\       http://oeis.org/search?q=id:A123456&fmt=text
\\

read("../OEIS-data.gp");

\\-----------------------------------------------------------------------------
\\ Using OEIS_data()

\\ The simplest use for OEIS-data.gp is to get a vector of the DATA section.
\\ Expect an error() if you don't have the necessary downloaded files.
\\
data = OEIS_data("A123456");

print("OEIS_data() = ",data);
print();

\\ The "offset" which is the intdex n of the first term can be had,
\\
offset = OEIS_offset("A123456");

print("OEIS_offset() = ",offset);
print();

\\ Or often both offset and data are warnted, so to get them together, in a
\\ vector of first the offset then the data (a vector within a vector).
\\
[offset,data] = OEIS_offset_and_data("A123456");

print("OEIS_offset_and_data() = ",OEIS_offset_and_data("A123456"));
print();


\\-----------------------------------------------------------------------------
\\ Using OEIS_data_func()

\\ OEIS_data_func() is a convenient way to get a function for the DATA,
\\ ready to be called like any other function.
\\ 
\\ This is handly for trying a few sequence values for a formula.
\\ Later an actual line of code from the sequence (or writing one!) may be
\\ wanted of course.
\\
\\ The return is a "closure" anonymous function.  Assign it to any desired
\\ local or global variable.
\\
\\ The function only has the DATA section so expect and error on giving an
\\ index n outside that domain.  (Give flag 'bfile to read a sequence
\\ b-file, if you have that.)
\\
func = OEIS_data_func("A123456");

{
  print1("OEIS_data_func() calls func(10..13) = ");
  for(n=10,13,
     print1(func(n), ","));
  print();
  print();
}


\\-----------------------------------------------------------------------------
\\ Using OEIS_data_gf()

\\ Many sequences have good relationships or expressions in terms of
\\ generating functions.  OEIS_data_gf() returns a PARI type t_SER series
\\ with sequence terms as series coefficients.
\\ 
\\ A t_SER series is preferred over an ordinary polynomial since the
\\ O(x^end) series "precision" propagates through calculations and
\\ combinations and so shows how many final good terms.  In particular
\\ powers or other growth don't become huge.
\\
gf = OEIS_data_gf("A123456");

print("OEIS_data_gf() = ",gf);
print("  type = ",type(gf));
print();


\\-----------------------------------------------------------------------------
print("end");
